# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from deep_agent_sdk.models.wrapped_response_health_response import WrappedResponseHealthResponse  # noqa: E501

class TestWrappedResponseHealthResponse(unittest.TestCase):
    """WrappedResponseHealthResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseHealthResponse:
        """Test WrappedResponseHealthResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseHealthResponse`
        """
        model = WrappedResponseHealthResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseHealthResponse(
                done = True,
                result = deep_agent_sdk.models.health_response.HealthResponse(
                    status = '', 
                    service = '', 
                    workers = { }, )
            )
        else:
            return WrappedResponseHealthResponse(
                result = deep_agent_sdk.models.health_response.HealthResponse(
                    status = '', 
                    service = '', 
                    workers = { }, ),
        )
        """

    def testWrappedResponseHealthResponse(self):
        """Test WrappedResponseHealthResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
